@@ -1,25 +1,44 @@
+import av
 import sys
 
 if sys.version_info[:2] < (3, 9):
     raise RuntimeError("This version of Outspeed requires at least Python 3.9")
 if sys.version_info[:2] >= (3, 13):
-    raise RuntimeError("This version of Outspeed does not support Python 3.13+")
+    raise RuntimeError(
+        "This version of Outspeed does not support Python 3.13+")
 
-import sentry_sdk
 
-sentry_sdk.init(
-    dsn="https://8842715aaa1b7fd845f8a55eea150394@o4506805333983232.ingest.us.sentry.io/4507603326795776",
-    # Set traces_sample_rate to 1.0 to capture 100%
-    # of transactions for performance monitoring.
-    traces_sample_rate=1.0,
-    # Set profiles_sample_rate to 1.0 to profile 100%
-    # of sampled transactions.
-    # We recommend adjusting this value in production.
-    profiles_sample_rate=1.0,
-)
-
-import coloredlogs
 import logging
+import platform
+import os
+
+import certifi
+import coloredlogs
+
+# Fix for "certificate verify failed" error in Python
+# Sets SSL cert file to certifi's trusted certificate bundle
+# ref: https://stackoverflow.com/a/42334357,
+# ref: https://www.happyassassin.net/posts/2015/01/12/a-note-about-ssltls-trusted-certificate-stores-and-platforms/
+
+
+def cross_platform_where():
+    if platform.system() == 'Darwin':  # macOS
+        if os.path.exists('/etc/ssl/cert.pem'):
+            return '/etc/ssl/cert.pem'
+        else:
+            return certifi.where()
+    elif os.name == 'posix':  # Linux and other POSIX systems
+        if os.path.exists('/etc/ssl/certs/ca-certificates.crt'):
+            return '/etc/ssl/certs/ca-certificates.crt'
+        elif os.path.exists('/etc/ssl/cert.pem'):
+            return '/etc/ssl/cert.pem'
+        else:
+            return certifi.where()
+    else:  # Windows and others
+        return certifi.where()
+
+
+os.environ['SSL_CERT_FILE'] = cross_platform_where()
 
 
 def configure_logging(level=logging.INFO):
@@ -33,7 +52,8 @@ def configure_logging(level=logging.INFO):
     # By default the install() function installs a handler on the root logger,
     # this means that log messages from your code and log messages from the
     # libraries that you use will all show up on the terminal.
-    coloredlogs.install(level=level, fmt="%(asctime)s %(levelname)s %(message)s")
+    coloredlogs.install(
+        level=level, fmt="%(asctime)s %(levelname)s %(message)s")
 
     # If you don't want to see log messages from libraries, you can pass a
 
@@ -46,31 +66,33 @@ configure_logging()
 
 try:
     from .app import App  # noqa: F401
-    from .data import AudioData, ImageData, TextData, SessionData  # noqa: F401
+    from .data import AudioData, ImageData, SessionData, TextData  # noqa: F401
+    from .ops.filter import filter  # noqa: F401
     from .ops.map import map  # noqa: F401
     from .ops.merge import merge  # noqa: F401
+    from .plugins.azure_stt import AzureTranscriber  # noqa: F401
     from .plugins.azure_tts import AzureTTS  # noqa: F401
     from .plugins.cartesia_tts import CartesiaTTS  # noqa: F401
     from .plugins.deepgram_stt import DeepgramSTT  # noqa: F401
     from .plugins.eleven_labs_tts import ElevenLabsTTS  # noqa: F401
     from .plugins.fireworks_llm import FireworksLLM  # noqa: F401
+    from .plugins.gemini_vision import GeminiVision  # noqa: F401
     from .plugins.groq_llm import GroqLLM  # noqa: F401
+    from .plugins.key_frame_detector import KeyFrameDetector  # noqa: F401
+    from .plugins.openai_llm import OpenAILLM  # noqa: F401
+    from .plugins.openai_realtime.openai_realtime import OpenAIRealtime  # noqa: F401
+    from .plugins.openai_vision import OpenAIVision  # noqa: F401
+    from .plugins.silero_vad import SileroVAD  # noqa: F401
     from .plugins.token_aggregator import TokenAggregator  # noqa: F401
+    from .plugins.whisper_stt import WhisperSTT  # noqa: F401
+    from .server import RealtimeServer  # noqa: F401
     from .streaming_endpoint import streaming_endpoint  # noqa: F401
-    from .streams import AudioStream, TextStream, VideoStream, VADStream  # noqa: F401
+    from .streams import AudioStream, TextStream, VADStream, VideoStream  # noqa: F401
+    from .tool import Tool  # noqa: F401
+    from .utils.clock import Clock  # noqa: F401
+    from .utils.vad import VADState  # noqa: F401
     from .web_endpoint import web_endpoint  # noqa: F401
     from .websocket import websocket  # noqa: F401
-    from .utils.clock import Clock  # noqa: F401
-    from .plugins.silero_vad import SileroVAD  # noqa: F401
-    from .utils.vad import VADState  # noqa: F401
-    from .plugins.whisper_stt import WhisperSTT  # noqa: F401
-    from .plugins.openai_llm import OpenAILLM  # noqa: F401
-    from .plugins.key_frame_detector import KeyFrameDetector  # noqa: F401
-    from .plugins.gemini_vision import GeminiVision  # noqa: F401
-    from .plugins.openai_vision import OpenAIVision  # noqa: F401
-    from .plugins.openai_realtime.openai_realtime import OpenAIRealtime  # noqa: F401
-    from .tool import Tool  # noqa: F401
-    from .server import RealtimeServer  # noqa: F401
 except Exception:
     print()
     print("#" * 50)
@@ -79,6 +101,10 @@ except Exception:
     print()
     raise
 
+
+av.logging.set_level(av.logging.PANIC)
+
+
 __all__ = [
     "configure_logging",
     "streaming_endpoint",
@@ -92,6 +118,7 @@ __all__ = [
     "DeepgramSTT",
     "GroqLLM",
     "TokenAggregator",
+    "filter",
     "map",
     "merge",
     "AzureTTS",
@@ -110,4 +137,5 @@ __all__ = [
     "OpenAIRealtime",
     "Tool",
     "RealtimeServer",
+    "AzureTranscriber",
 ]
