@@ -1,6 +1,7 @@
 import asyncio
 import logging
 import os
+import traceback
 from typing import Any, Callable, Optional, Type
 
 from dotenv import load_dotenv
@@ -98,13 +99,22 @@ class RealtimeApp:
             else:
                 loop.run_until_complete(asyncio.gather(RealtimeServer().start()))
         except asyncio.CancelledError:
-            logging.error("RealtimeServer was cancelled")
+            pass
         except Exception as e:
             logging.error(f"Error in RealtimeApp: {e}")
-
+            logging.error(traceback.format_exc())
+        except KeyboardInterrupt:
+            logging.error("RealtimeApp was interrupted by the user")
         finally:
             # Run teardown
+            try:
+                loop.run_until_complete(RealtimeServer().shutdown())
+            except Exception as e:
+                pass
             try:
                 loop.run_until_complete(self._user_cls_instance.teardown())
             except Exception as e:
                 pass
+
+            # Forcefully exit the program
+            os._exit(1)
