@@ -5,11 +5,11 @@ from typing import Optional
 
 import aiohttp
 
-from outspeed.data import AudioData
+from outspeed.data import AudioData, SessionData
 from outspeed.plugins.base_plugin import Plugin
-from outspeed.streams import AudioStream, TextStream
+from outspeed.streams import AudioStream, TextStream, VADStream
 from outspeed.utils import tracing
-from outspeed.data import SessionData
+from outspeed.utils.vad import VADState
 
 logger = logging.getLogger(__name__)
 
@@ -31,6 +31,9 @@ class ElevenLabsTTS(Plugin):
         output_format: str = "pcm_16000",
         optimize_streaming_latency: int = 4,
         stream: bool = True,
+        stability: float = 0.5,
+        similarity_boost: float = 0.8,
+        volume: float = 1.0,
     ):
         """
         Initialize the ElevenLabsTTS plugin.
@@ -65,6 +68,8 @@ class ElevenLabsTTS(Plugin):
             self.sample_rate = 16000
         elif self._output_format == "pcm_24000":
             self.sample_rate = 24000
+        elif self._output_format == "pcm_44100":
+            self.sample_rate = 44100
         elif self._output_format == "mp3_22050_32":
             self.sample_rate = 22050
         elif self._output_format == "mp3_44100_128":
@@ -80,6 +85,10 @@ class ElevenLabsTTS(Plugin):
         self.interrupt_queue: Optional[asyncio.Queue] = None
         self._interrupt_task: Optional[asyncio.Task] = None
 
+        self.stability = stability
+        self.similarity_boost = similarity_boost
+        self.volume = volume
+
     def run(self, input_queue: TextStream) -> AudioStream:
         """
         Start the text-to-speech synthesis process.
@@ -117,7 +126,11 @@ class ElevenLabsTTS(Plugin):
                     # Prepare API request
                     url = f"https://api.elevenlabs.io/v1/text-to-speech/{self._voice_id}"
                     url += "/stream" if self._stream else ""
-                    payload = {"text": text_chunk, "model_id": self._model}
+                    payload = {
+                        "text": text_chunk,
+                        "model_id": self._model,
+                        "voice_settings": {"stability": self.stability, "similarity_boost": self.similarity_boost},
+                    }
                     querystring = {
                         "output_format": self._output_format,
                         # "optimize_streaming_latency": self._optimize_streaming_latency,
@@ -150,16 +163,22 @@ class ElevenLabsTTS(Plugin):
                                     if len(audio_buffer) >= 4000:
                                         if len(audio_buffer) % 2 != 0:
                                             self.output_queue.put_nowait(
-                                                AudioData(audio_buffer[:-1], sample_rate=self.sample_rate)
+                                                AudioData(
+                                                    audio_buffer[:-1], sample_rate=self.sample_rate
+                                                ).change_volume(self.volume)
                                             )
                                             audio_buffer = audio_buffer[-1:]
                                         else:
                                             self.output_queue.put_nowait(
-                                                AudioData(audio_buffer, sample_rate=self.sample_rate)
+                                                AudioData(audio_buffer, sample_rate=self.sample_rate).change_volume(
+                                                    self.volume
+                                                )
                                             )
                                             audio_buffer = b""
                             if len(audio_buffer) > 0:
-                                self.output_queue.put_nowait(AudioData(audio_buffer, sample_rate=self.sample_rate))
+                                self.output_queue.put_nowait(
+                                    AudioData(audio_buffer, sample_rate=self.sample_rate).change_volume(self.volume)
+                                )
                                 audio_buffer = b""
                         else:
                             # Non-streaming mode: process entire response at once
@@ -189,25 +208,35 @@ class ElevenLabsTTS(Plugin):
 
     async def _interrupt(self):
         """
-        Handle interruptions to the TTS process, e.g., when the user starts speaking.
+        Handle interruptions (e.g., when the user starts speaking).
+        Cancels ongoing TTS generation and clears the output queue.
         """
         while True:
-            user_speaking = await self.interrupt_queue.get()
-            if self._generating and user_speaking:
+            vad_state: VADState = await self.interrupt_queue.get()
+            if vad_state == VADState.SPEAKING and (not self.input_queue.empty() or not self.output_queue.empty()):
                 if self._task:
                     self._task.cancel()
+                    try:
+                        await self._task
+                    except asyncio.CancelledError:
+                        pass
                 while not self.output_queue.empty():
                     self.output_queue.get_nowait()
-                logger.info("Done cancelling TTS")
+                while not self.input_queue.empty():
+                    self.input_queue.get_nowait()
+                logging.info("Done cancelling TTS")
                 self._generating = False
                 self._task = asyncio.create_task(self.synthesize_speech())
 
-    async def set_interrupt(self, interrupt_queue: asyncio.Queue):
+    def set_interrupt_stream(self, interrupt_stream: VADStream):
         """
-        Set up the interrupt mechanism for the TTS process.
+        Set up the interrupt queue and start the interrupt handling task.
 
         Args:
-            interrupt_queue (asyncio.Queue): Queue for receiving interrupt signals.
+            interrupt_stream (VADStream): The stream for receiving interrupt signals.
         """
-        self.interrupt_queue = interrupt_queue
+        if isinstance(interrupt_stream, VADStream):
+            self.interrupt_queue = interrupt_stream
+        else:
+            raise ValueError("Interrupt stream must be a VADStream")
         self._interrupt_task = asyncio.create_task(self._interrupt())
