@@ -55,7 +55,7 @@ class OpenAIRealtime(Plugin):
         silence_duration_ms: int = 200,
         vad_threshold: float = 0.5,
         initiate_conversation_with_greeting: Optional[str] = None,
-        tools: Optional[list[Tool]] = None,
+        tools: list[Tool] = [],
         tool_choice: str = "auto",
         respond_to_tool_calls: bool = True,
     ):
@@ -112,7 +112,7 @@ class OpenAIRealtime(Plugin):
         self.respond_to_tool_calls = respond_to_tool_calls
         self._initialize_handlers()
 
-    def run(self, text_queue: TextStream, audio_queue: AudioStream) -> ByteStream:
+    def run(self, text_queue: TextStream, audio_queue: AudioStream):
         """
         Start the TTS synthesis process.
 
@@ -277,7 +277,7 @@ class OpenAIRealtime(Plugin):
     async def close(self):
         """Close the websocket connection and cancel the main task."""
         if self._ws:
-            await self._ws.close()
+            asyncio.create_task(self._ws.close())
         if self._task:
             self._task.cancel()
 
@@ -420,3 +420,18 @@ class OpenAIRealtime(Plugin):
 
     async def _handle_unknown(self, msg):
         logging.error("Unknown response type in OpenAI Realtime: %s \n", msg)
+
+    async def _interrupt_all(self):
+        """
+        Handle interruptions (e.g., when the user starts speaking).
+        Cancels ongoing TTS generation and clears the output queue.
+        """
+        while not self.input_queue.empty():
+            self.input_queue.get_nowait()
+        while not self.text_output_queue.empty():
+            self.text_output_queue.get_nowait()
+        while not self.audio_output_queue.empty():
+            self.audio_output_queue.get_nowait()
+        await self._ws.send(json.dumps({"type": ClientEvent.INPUT_AUDIO_BUFFER_CLEAR}))
+        await self._ws.send(json.dumps({"type": ClientEvent.RESPONSE_CANCEL}))
+        logging.info("Done cancelling TTS generation \n")
