@@ -1,7 +1,15 @@
+from enum import Enum
+
 import numpy as np
 import pyloudnorm as pyln
 
 
+class AudioCodec(str, Enum):
+    OPUS = "audio/opus"
+    PCMU = "audio/PCMU"
+    PCMA = "audio/PCMA"
+
+
 def normalize_value(value, min_value, max_value):
     normalized = (value - min_value) / (max_value - min_value)
     normalized_clamped = max(0, min(1, normalized))
